@@ -1,4 +1,4 @@
-errorModelSelection <- function(project=NULL, pen.coef=NULL, nb.model=1) {
+errorModelSelection <- function(project=NULL, pen.coef=NULL, nb.model=1, f.min=0.001) {
   
   if (!is.null(project))
     mlx.loadProject(project)
@@ -37,7 +37,7 @@ errorModelSelection <- function(project=NULL, pen.coef=NULL, nb.model=1) {
   if (nb.model==1) {
     res.errorModel <- NULL
     for (i.out in (1:n.out)) {
-
+      
       # name.predi <- obs.model$prediction[[i.contModel[i.out]]]
       # name.obsi <- names(obs.model$prediction[i.contModel[i.out]])
       # y.obsi <- d[[name.obsi]][[name.obsi]]
@@ -48,7 +48,7 @@ errorModelSelection <- function(project=NULL, pen.coef=NULL, nb.model=1) {
       kt <- 0
       while(test | kt<10) {
         kt <- kt+1
-        resi <- tryCatch(computeBIC(y.obs=y.obsi, y.pred=y.predi, pen.coef=pen.coef[i.out], nb.model=nb.model),
+        resi <- tryCatch(computeBIC(y.obs=y.obsi, y.pred=y.predi, pen.coef=pen.coef[i.out], nb.model=nb.model, f.min=f.min),
                          error = function(e) e)
         if (inherits(resi, "error")) {
           print("error !!!")
@@ -72,7 +72,7 @@ errorModelSelection <- function(project=NULL, pen.coef=NULL, nb.model=1) {
       # y.predi <- pred[[name.predi]][[name.predi]]
       y.obsi <- y.obs[[y.name[i.out]]][[y.name[i.out]]]
       y.predi <- pred[[y.pred[i.out]]][[y.pred[i.out]]]
-      resi <- tryCatch(computeBIC(y.obs=y.obsi, y.pred=y.predi, pen.coef=pen.coef[i.out], nb.model=nb.model),
+      resi <- tryCatch(computeBIC(y.obs=y.obsi, y.pred=y.predi, pen.coef=pen.coef[i.out], nb.model=nb.model, f.min=f.min),
                        error = function(e) e)
       if (inherits(resi, "error")) {
         print("error !!!")
@@ -80,7 +80,7 @@ errorModelSelection <- function(project=NULL, pen.coef=NULL, nb.model=1) {
         mlx.loadProject("foo.mlxtran")
         pred <- getSimulatedPredictions()
         y.predi <- pred[[y.pred[i.out]]][[y.pred[i.out]]]
-        resi <- computeBIC(y.obs=y.obsi, y.pred=y.predi, pen.coef=pen.coef[i.out], nb.model=nb.model)
+        resi <- computeBIC(y.obs=y.obsi, y.pred=y.predi, pen.coef=pen.coef[i.out], nb.model=nb.model, f.min=f.min)
       }
       res.errorModel[[i.out]] <- resi
       names(res.errorModel)[i.out] <- y.name[i.out]
@@ -101,7 +101,7 @@ e.min2 <- function(x,y.pred,y.obs) {
   return(e)
 }
 
-computeBIC <- function(y.obs, y.pred, pen.coef, nb.model) {
+computeBIC <- function(y.obs, y.pred, pen.coef, nb.model, f.min) {
   
   y.pos <- (min(y.obs) >= 0) 
   nrep <- length(y.pred)/length(y.obs)
@@ -112,6 +112,7 @@ computeBIC <- function(y.obs, y.pred, pen.coef, nb.model) {
     y.obs <- y.obs[iy]
     y.pred <- y.pred[iy]
   }
+  yb <- mean(abs(y.obs))
   
   # if (sum(is.na(y.pred))+sum(is.nan(y.pred))>0)
   #   browser()
@@ -124,19 +125,28 @@ computeBIC <- function(y.obs, y.pred, pen.coef, nb.model) {
   x.min <- nlm(e.min1,c(a.comb2,b.comb2),y.pred,y.obs)
   a.comb1 <- x.min$estimate[1]
   b.comb1 <- x.min$estimate[2]
-
+  
   x.min <- nlm(e.min2,c(a.comb1,b.comb1),y.pred,y.obs)
   a.comb2 <- abs(x.min$estimate[1])
   b.comb2 <- abs(x.min$estimate[2])
-
-    if (y.pos == TRUE ) {
+  
+  if (a.comb2/yb < b.comb2*f.min) 
+    a.comb2 <- 0
+  else if (b.comb2 < a.comb2/yb*f.min) 
+    b.comb2 <- 0
+  if (a.comb1/yb < b.comb1*f.min) 
+    a.comb1 <- 0
+  else if (b.comb1 < a.comb1/yb*f.min) 
+    b.comb1 <- 0
+  
+  if (y.pos == TRUE ) {
     b.prop <- sqrt(mean(((y.obs/y.pred-1)^2)))
     
     a.expo <- sqrt(mean((log(y.obs)-log(y.pred))^2))
     
     error.model=c("constant", "proportional", "combined1","combined2","exponential")
-    sigma2 <- cbind(a.cons^2, (b.prop*y.pred)^2, (a.comb1+b.comb1*y.pred)^2, 
-                    a.comb2^2+(b.comb2*y.pred)^2, a.expo^2)
+    # sigma2 <- cbind(a.cons^2, (b.prop*y.pred)^2, (a.comb1+b.comb1*y.pred)^2, 
+    #                 a.comb2^2+(b.comb2*y.pred)^2, a.expo^2)
     sigma2 <- cbind(a.cons^2, (b.comb2*y.pred)^2, (a.comb1+b.comb1*y.pred)^2, 
                     a.comb2^2+(b.comb2*y.pred)^2, a.expo^2)
     df <- c(1, 1, 2, 2, 1)
@@ -147,7 +157,7 @@ computeBIC <- function(y.obs, y.pred, pen.coef, nb.model) {
   }
   
   ll <- pen <- bic <- NULL
-    for (k in 1:length(error.model)) {
+  for (k in 1:length(error.model)) {
     if (error.model[k] == "exponential")
       ll <- c(ll, - 0.5*sum( (log(y.obs)-log(y.pred))^2/(a.expo^2) + log(2*pi*(a.expo^2)) + 2*log(y.obs) )/nrep)
     else
